==> haskell-roman-numerals-0.5.1.5-31-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 roman-numerals
version:              0.5.1.5
visibility:           public
id:                   roman-numerals-0.5.1.5-Ky2Li6P3sYXDMxeR51IilI
key:                  roman-numerals-0.5.1.5-Ky2Li6P3sYXDMxeR51IilI
license:              BSD-3-Clause
copyright:            2009–2014 Roel van Dijk
maintainer:           Roel van Dijk <vandijk.roel@gmail.com>
author:               Roel van Dijk <vandijk.roel@gmail.com>
stability:            stable
homepage:             https://github.com/roelvandijk/roman-numerals
synopsis:             Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.

category:             Numerical, Parsing
abi:                  8d8a096e8099565cd57c364ad1f97ddc
exposed:              True
exposed-modules:      Text.Numeral.Roman
import-dirs:          /usr/lib/ghc-9.2.8/site-local/roman-numerals-0.5.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/roman-numerals-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-roman-numerals
hs-libraries:         HSroman-numerals-0.5.1.5-Ky2Li6P3sYXDMxeR51IilI
depends:
    base-4.16.4.0 base-unicode-symbols-0.2.4.2-LxaiYZxX2IHCdJ6KOk7ePF
    bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock

haddock-html:         /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-roman-numerals-0.5.1.5-32-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 roman-numerals
version:              0.5.1.5
visibility:           public
id:                   roman-numerals-0.5.1.5-4h8wRNsyXj8AMJjSeyXZNq
key:                  roman-numerals-0.5.1.5-4h8wRNsyXj8AMJjSeyXZNq
license:              BSD-3-Clause
copyright:            2009–2014 Roel van Dijk
maintainer:           Roel van Dijk <vandijk.roel@gmail.com>
author:               Roel van Dijk <vandijk.roel@gmail.com>
stability:            stable
homepage:             https://github.com/roelvandijk/roman-numerals
synopsis:             Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.

category:             Numerical, Parsing
abi:                  23b8a82054e796ad2d494b9fb29b8fe8
exposed:              True
exposed-modules:      Text.Numeral.Roman
import-dirs:          /usr/lib/ghc-9.4.8/site-local/roman-numerals-0.5.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/roman-numerals-0.5.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/roman-numerals-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-roman-numerals
hs-libraries:         HSroman-numerals-0.5.1.5-4h8wRNsyXj8AMJjSeyXZNq
depends:
    base-4.17.2.1 base-unicode-symbols-0.2.4.2-DGP2ohBQv5PB4jg5C9PUqH
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock

haddock-html:         /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
